import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  format,
  scaleTime,
  area,
  curveBasis,
  max
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const title = '-';
  
  const xValue = d => d.year;
  const xAxisLabel = 'Time';
  
  const yValue = d => d.population;
  const circleRadius = 6;
  const yAxisLabel = 'Temperature';
  
  const margin = { top: 60, right: 40, bottom: 88, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
  
  const yScale = scaleLinear()
    .domain([0 , max(data, yValue)])
    .range([innerHeight, 0])
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const yAxisTickFormat = number =>
    format('.1s')(number)
      .replace('G', 'B');
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15)
  	.ticks(6);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10)
  .tickFormat(yAxisTickFormat);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -93)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 75)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  
  const myArea = area()
    .x((d) =>  xScale(d.year))
    .y0(innerHeight)
  	.y1((d) =>  yScale(d.population))
  	.curve(curveBasis);
  
  g.append('path')
  	.attr('class', 'line-path')
  	.attr('d', myArea(data));
  

  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};

csv('https://vizhub.com/curran/datasets/world-population-by-year-2015.csv')
  .then(data => {

    data.forEach(d => {
      d.population = +d.population;
   		d.year = new Date(d.year);
    });

    render(data);
  });